# supercontrast

`supercontrast` is a package for easily running models from a variety of providers.

## Installation

```bash
pip install supercontrast
```

## Usage

```python
from supercontrast import supercontrast_client

```

## Contributing

We welcome contributions to the project! To contribute, please follow these steps:

### 1. Clone the repo

```bash
git clone https://github.com/supercontrast/supercontrast.git
```

### 2. Install package

```bash
pip install -e .[dev]
```

### 3. Run linting

```bash
black .
isort .
```

### 4. Run tests

```bash
pytest
```

### 5. Submit a PR

Submit a PR to the main branch! We will review and merge your PR.









